# Naver Cafe Archive

🇰🇷 Naver Cafe Archive Module

<a href="https://pypi.org/project/spdlqj/">
  <img alt="PyPI Module Version" src="https://img.shields.io/pypi/v/spdlqj?style=for-the-badge&labelColor=000" />
</a>
<a href="https://opensource.org/licenses/MIT">
    <img alt="License: MIT" src="https://img.shields.io/badge/License-MIT-brightgreen.svg?style=for-the-badge&labelColor=000" />
</a>

```bash
pip3 install spdlqj
```

<img alt="Result_1" src="./docs/result_1.png" />
<img alt="Result_2" src="./docs/result_2.png" />
